<?php

class MLumen_Descriptor_Bulk_Posts {
	/**
	 * @var Mlumen_Options
	 */
	private $api_options;

	/**
	 * @var Mlumen_Api_Descriptor
	 */
	private $api_descriptor;

	public function __construct( Mlumen_Options $api_options, Mlumen_Api_Descriptor $api_descriptor ) {
		$this->api_options    = $api_options;
		$this->api_descriptor = $api_descriptor;

		add_action( 'wp_ajax_savedescriptors', array( $this, 'save_descriptors' ) );
		add_action( 'wp_ajax_postidsfordescriptor', array( $this, 'all_post_ids_for_descriptors' ) );
	}

	/**
	 * Add bulk actions to select
	 */
	public function add_bulk_actions() {
		$post_types = $this->api_options->get_post_types_mlumen_exists();

		foreach ( $post_types as $post ) {
			add_filter( 'bulk_actions-edit-' . $post, function ( $bulk_array ) {

				$bulk_array['descriptor_selected'] = __( 'Tagi DBN - taguj zaznaczone', 'mlumen' );
				$bulk_array['descriptor_all']      = __( 'Tagi DBN - taguj wszystkie', 'mlumen' );

				return $bulk_array;
			} );
		}

		add_action( 'admin_notices', array($this, 'add_modal_window') );
	}


	/**
	 * Show modal window
	 */
	public function add_modal_window() {
		?>

		<div id="descriptor_modal" style="display:none">
             <form id="bulk_form">
                  <p id="bulk_start_message" style="display:none">
                        <strong><?php _e( 'Rozpocznij tagowanie ', 'mlumen' ); ?></strong>
                  </p>
                  <span id="bulk_progress_message" class="bulk-progress-message">
                     <p>
	                     <strong>
                            <?php _e( 'Przetworzono ', 'mlumen' ); ?><span id="bulk_count"></span> <?php _e( ' z  ', 'mlumen' ); ?> <span id="bulk_count_all"></span>
                        </strong>
                     </p>
                      <div class="bulk-progress-container">
                        <div class="bulk-progress-loading"><span></span></div>
                      </div>
                 </span>
                 <p id="bulk_end_message" style="display:none">
                    <strong><?php _e( 'Tagowanie zostało zakończone', 'mlumen' ); ?></strong>
                    <br>
                    <span><?php _e( 'Za chwilę strona zostanie automatycznie odświeżona ...', 'mlumen' ); ?></span>
                 </p>
                 <input type="hidden" name="bulk_type"  />
                 <input type="hidden" name="post_type"  />
                 <button id="bulk_action_run"  class="button button-primary" disabled><?php _e( 'Rozpocznij oznaczanie postów', 'mlumen' ); ?></button>
                 <button id="bulk_action_stop"  class="button button-primary" disabled><?php _e( 'Anuluj', 'mlumen' ); ?></button>
             </form>
        </div>

		<?php
	}

	/**
	 * Get descriptors
	 */
	public function save_descriptors() {
		if ( ! isset( $_POST['post_id'] ) ) {
			wp_send_json( array(
				'status'        => false,
				'tags'          => array(),
				'error_message' => __( 'Brak post ID', 'mlumen' )
			) );
			wp_die();
		}

		$post = get_post( (int) $_POST['post_id'] );

		if ( ! isset( $post->ID ) ) {
			wp_send_json( array(
				'status'        => false,
				'tags'          => array(),
				'error_message' => __( 'Błąd odczytu posta', 'mlumen' )
			) );
			wp_die();
		}

		$tags_names = array();
		$text       = apply_filters( 'the_content', $post->post_content );

		if ( empty( $text ) ) {
			wp_send_json( array(
				'status'        => false,
				'tags'          => array(),
				'error_message' => __( 'Brak treści', 'mlumen' )
			) );
			wp_die();
		}

		if ( ! $this->api_descriptor->get_suggest( $text ) ) {
			wp_send_json( array(
				'status'        => false,
				'tags'          => array(),
				'error_message' => $this->api_descriptor->error_message
			) );
			wp_die();
		}

		$fields = $this->api_options->get_taxonomy_for_post_save( $post->post_type );

		if ( count( $fields ) > 0 ) {
			$tags_names = array_map( function ( $item ) {
				return $item['name'];
			}, $this->api_descriptor->data );

			if ( $tags_names !== false ) {
				foreach ( $fields as $field ) {
					wp_set_post_terms( $post->ID, $tags_names, $field, $this->api_options->options['taxonomy_append'] );
				}
			}
		}

		wp_send_json( array(
			'status'        => true,
			'fields'        => $fields,
			'tags'          => $tags_names,
			'error_message' => $this->api_descriptor->error_message
		) );
		wp_die();
	}

	/**
	 * Get all post ids for descriptors
	 */
	public function all_post_ids_for_descriptors() {
		if ( ! isset( $_POST['posttype'] ) ) {
			wp_send_json( array(
				'status'        => false,
				'ids'           => array(),
				'error_message' => __( 'Brak typu postów', 'mlumen' )
			) );
			wp_die();
		}

		$count_posts_query = new WP_Query( array(
			'post_type'      => sanitize_text_field( $_POST['posttype'] ),
			'posts_per_page' => - 1
		) );

		$posts_ids = wp_list_pluck( $count_posts_query->posts, 'ID' );

		wp_send_json( array(
			'status' => true,
			'ids'    => $posts_ids,
			'count'  => count( $posts_ids )
		) );
		wp_die();
	}
}