<?php

class Mlumen_Options {
	/**
	 * @var array
	 */
	private $options_default = array(
		'active'                => false,
		'token'                 => '',
		'email'                 => '',
		'taxonomy_prompts_type' => 2,   // 1 - manual add select, 2 - manual add all, 3 - auto add in save
		'taxonomy_append'       => true,
		'post_create_taxonomy'  => array(),
		'taxonomy_prompts'      => array('post' => array('post_tag')),
		'limit_tags'            => 12,
		'minimal_tags_score'    => '0.12'
	);

	/**
	 * @var array
	 */
	public $options;

	public function __construct() {
		$this->load_options();
	}

	/**
	 * Load options
	 */
	public function load_options() {
		$options = get_option( 'mlumen_options' );

		if ( is_array( $options ) ) {
			$this->options = array_merge( $this->options_default, $options );
		} else {
			$this->options = $this->options_default;
		}
	}

	/**
	 * Save options
	 *
	 * @return bool
	 */
	public function save_options( array $data = array() ) {
		$this->options = array_merge( $this->options, $data );

		update_option( 'mlumen_options', $this->options );

		return true;
	}

	/**
	 * Remove options (set default or permanent delete)
	 *
	 * @return bool
	 */
	public function delete_options( bool $permanent = false ) {
		if ( $permanent ) {
			return delete_option( 'mlumen_options' );
		}

		return $this->save_options( $this->options_default );
	}

	/**
	 * Get options
	 *
	 * @return array
	 */
	public function get_options() {
		return $this->options;
	}

	/**
	 * Check blog is active on not active
	 *
	 * @return bool
	 */
	public function is_active_blog() {
		return $this->options['active'];
	}

	/**
	 * Get taxonomy for prompts mLumen
	 *
	 * @return array
	 */
	public function get_taxonomy_prompts() {
		$register_taxonomy = array();

		if ( isset( $this->options['taxonomy_prompts'] ) ) {
			foreach ( $this->options['taxonomy_prompts'] as $post_types ) {
				if ( isset( $post_types ) ) {
					foreach ( $post_types as $taxonomy ) {
						$register_taxonomy[] = $taxonomy;
					}
				}
			}
		}

		return $register_taxonomy;
	}

	/**
	 * Get Post Types where mLumen prompts exist
	 *
	 * @return array
	 */
	public function get_post_types_mlumen_exists() {
		$post_create_taxonomy = isset( $this->options['post_create_taxonomy'] ) ? $this->options['post_create_taxonomy'] : array();

		$taxonomy_prompts = array_keys( $this->options['taxonomy_prompts'] );

		$post_types = array_merge( $post_create_taxonomy, $taxonomy_prompts );

		$post_types = array_unique( $post_types );

		return $post_types;
	}


	/**
	 * Get taxonomy for post save
	 *
	 * @return array
	 */
	public function get_taxonomy_for_post_save( string $post_type ) {
		$fields = array();

		if ( in_array( $post_type, $this->options['post_create_taxonomy'] ) ) {
			$fields[] = $post_type . '_mlumen';
		} elseif ( isset( $this->options['taxonomy_prompts'][ $post_type ] ) && is_array( $this->options['taxonomy_prompts'][ $post_type ] ) ) {
			$fields = $this->options['taxonomy_prompts'][ $post_type ];
		}

		return $fields;
	}

}